#
# k2htpdtor for K2HASH TRANSACTION PLUGIN.
#
# Copyright 2015 Yahoo Japan Corporation.
#
# K2HASH TRANSACTION PLUGIN is programmable I/F for processing
# transaction data from modifying K2HASH data.
#
# For the full copyright and license information, please view
# the LICENSE file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Mon Jun 20 2016
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.40

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: Shared library for K2HASH TRANSACTION PLUGIN.
Name: k2htpdtor
Version: 1.0.40
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Databases
URL: https://github.com/yahoojapan/k2htpdtor
Source0: https://github.com/yahoojapan/k2htpdtor/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: libfullock%{?_isa} >= 1.0.50, k2hash%{?_isa} >= 1.0.87, chmpx%{?_isa} >= 1.0.99
BuildRequires: git-core gcc-c++ make libtool libfullock-devel >= 1.0.50, k2hash-devel >= 1.0.87, chmpx-devel >= 1.0.99, libyaml-devel, nss-devel

%description
k2htpdtor is K2HASH DISTRIBUTED TRANSACTION OF REPEATER. This shared
library is transaction plugin for k2hash library. The k2hash library
has programmable I/F for processing transaction data from modifying
K2HASH data.

The k2htpdtor forwards the operation to other servers connecting by
CHMPX. The k2htpdtor plugin is called by k2hash transaction plugin
logic after the operation is occurred by changing the k2hash data.

The k2htpdtor need to get only one parameter for working. The basi-
cally parameter is the configuration file path as same as the file for
setting CHMPX on slave side.

The other type, the extended type parameter is the configuration file
for k2hdtor. The k2hdtor configuration file is INI file type, and it
can have K2HTPDTOR_BROADCAST, K2HTPDTOR_CHMPXCONF, K2HTPDTOR_EXCEPT_KEY
and K2HTPDTOR_FILE key in K2HTPDTOR section.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.so' -exec rm -f {} ';'
mkdir -p %{buildroot}/var/lib/antpickax

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%if 0%{?rhel} == 6
%clean
rm -rf %{buildroot}
%endif

%files
%if 0%{?rhel} == 6
%doc COPYING
%defattr(-,root,root)
%else
%license COPYING
%endif
%doc README AUTHORS ChangeLog
%{_libdir}/*.so.*
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_bindir}/*
%dir %attr(0777,root,root) /var/lib/antpickax

%changelog
* Thu Aug 31 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.40-1
- Updated tool scripts and support OSs - #63
- Fixed bugs about test scripts - #62
- Fixed .gitignore to exclude APKBUILD.templ - #61

* Fri May 12 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.39
- Updated versions of dependent packages - #59

* Thu Mar 02 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.38
- Updated building/packaging logic for ALPINE - #57

* Fri Feb 10 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.37
- Update package dependencies and remove unnecessary packages - #55

* Thu Feb 09 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.36
- Fixed imagetypevars.sh for changing base packages #53
- Changed CI process flow/OSs and added Alpine OS - #51
- Updated header and footer in comment lines - #50
- Updated issue/pullrequest templates - #48
- Added ShellCheck processing and reviewed cppcheck - #47
- Eliminated unnecessary copies in build_helper.sh - #46
- Updated docker/login-action from v1 to v2 - #45
- Shared Docker image build logic with other products - #44
- Updated github actions process and support os, and fixed bugs - #43
- Updated scripts for adding grep params and replacing which to command - #42
- Updated common build scripts - #41
- Updated Antpickax common scripts and tools under the buildutils directory - #40
- Fixed errors reported by cppcheck 2.9 - #39
- Enabled external customization of configure.ac and fixed for building - #38

* Mon Sep 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.35
- Bumpup for updating the base Docker image becase of CHMPX updated

* Fri Aug 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.34
- Fixed Dockerfile template for calling ldconfig - #35

* Tue Aug 17 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.33
- Added docker build and push in Github Actions - #33
- Functional improvements and bug fixes - #32

* Thu Dec 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.32
- Fixed centos8 build and removed centos6 build - #29

* Tue Nov 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.31
- Switched Travis CI to Github actions and extended supported OS - #27
- Fixed bugs detected by cppcheck - #26

* Fri Dec 20 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.30
- Updated version of dependency packages - #24

* Tue Mar 12 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.29
- Fixed codes for cppcheck 1.87 - #21

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.28
- Fixed misspelling, and etc - #18
- Reflected the spelling check result for all sources(2) - #17
- Added check using cppcheck - #16
- Reflected the spelling check result for all sources - #15

* Tue Dec 11 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.27
- Updated common build tool files

* Thu Dec 06 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.26
- Changed to strict packaging and changed documents

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.25
- Fixed destructing code for corresponding to SIOF, etc

* Mon Jul 02 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.24
- Revert subdir-objects automake option in src directory
- avoid static object initialization order problem(SIOF)

* Thu May 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.23
- Cleanup credit comments in sources and Modified etc
- Changed build logic to new for rpm/debian packaging
- Fixed a filename typo of make_variables.sh

* Mon Mar 26 2018 Hirotaka Wakabayashi <hiwakaba@yahoo-corp.jp> 1.0.22
- Updated submodule dependency for chmpx/k2hash

* Tue Mar 28 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.21
- Added lib_version_for_link option to make_valiables.sh
- Updated submodule dependency for chmpx/k2hash/fullock

* Tue Feb 14 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.20
- Updated dependency for fixing bugs in libfullock
- Updated submodules and changed .travis.yaml - #1

* Wed Dec 07 2016 Takeshi Nakatani <ggtakec@gmail.com> 1.0.19
- First version of open source on Github
